==> quarkus-vertx-http-0.23.2-sources.jar: io/quarkus/vertx/http/runtime/HttpConfiguration$$accessor.java <==
package io.quarkus.vertx.http.runtime;
public final class HttpConfiguration$$accessor {
    private HttpConfiguration$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_corsEnabled(Object __instance) {
        return ((HttpConfiguration)__instance).corsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_corsEnabled(Object __instance, boolean corsEnabled) {
        ((HttpConfiguration)__instance).corsEnabled = corsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static int get_port(Object __instance) {
        return ((HttpConfiguration)__instance).port;
    }
    @SuppressWarnings("unchecked")
    public static void set_port(Object __instance, int port) {
        ((HttpConfiguration)__instance).port = port;
    }
    @SuppressWarnings("unchecked")
    public static int get_testPort(Object __instance) {
        return ((HttpConfiguration)__instance).testPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_testPort(Object __instance, int testPort) {
        ((HttpConfiguration)__instance).testPort = testPort;
    }
    @SuppressWarnings("unchecked")
    public static Object get_host(Object __instance) {
        return ((HttpConfiguration)__instance).host;
    }
    @SuppressWarnings("unchecked")
    public static void set_host(Object __instance, Object host) {
        ((HttpConfiguration)__instance).host = (String)host;
    }
    @SuppressWarnings("unchecked")
    public static int get_sslPort(Object __instance) {
        return ((HttpConfiguration)__instance).sslPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_sslPort(Object __instance, int sslPort) {
        ((HttpConfiguration)__instance).sslPort = sslPort;
    }
    @SuppressWarnings("unchecked")
    public static int get_testSslPort(Object __instance) {
        return ((HttpConfiguration)__instance).testSslPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_testSslPort(Object __instance, int testSslPort) {
        ((HttpConfiguration)__instance).testSslPort = testSslPort;
    }
    @SuppressWarnings("unchecked")
    public static Object get_cors(Object __instance) {
        return ((HttpConfiguration)__instance).cors;
    }
    @SuppressWarnings("unchecked")
    public static void set_cors(Object __instance, Object cors) {
        ((HttpConfiguration)__instance).cors = (io.quarkus.vertx.http.runtime.cors.CORSConfig)cors;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ssl(Object __instance) {
        return ((HttpConfiguration)__instance).ssl;
    }
    @SuppressWarnings("unchecked")
    public static void set_ssl(Object __instance, Object ssl) {
        ((HttpConfiguration)__instance).ssl = (ServerSslConfig)ssl;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ioThreads(Object __instance) {
        return ((HttpConfiguration)__instance).ioThreads;
    }
    @SuppressWarnings("unchecked")
    public static void set_ioThreads(Object __instance, Object ioThreads) {
        ((HttpConfiguration)__instance).ioThreads = (java.util.OptionalInt)ioThreads;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_virtual(Object __instance) {
        return ((HttpConfiguration)__instance).virtual;
    }
    @SuppressWarnings("unchecked")
    public static void set_virtual(Object __instance, boolean virtual) {
        ((HttpConfiguration)__instance).virtual = virtual;
    }
    @SuppressWarnings("unchecked")
    public static Object get_limits(Object __instance) {
        return ((HttpConfiguration)__instance).limits;
    }
    @SuppressWarnings("unchecked")
    public static void set_limits(Object __instance, Object limits) {
        ((HttpConfiguration)__instance).limits = (ServerLimitsConfig)limits;
    }
    public static Object construct() {
        return new HttpConfiguration();
    }
}

==> quarkus-vertx-http-0.26.1-sources.jar: io/quarkus/vertx/http/runtime/HttpConfiguration$$accessor.java <==
package io.quarkus.vertx.http.runtime;
public final class HttpConfiguration$$accessor {
    private HttpConfiguration$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_corsEnabled(Object __instance) {
        return ((HttpConfiguration)__instance).corsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_corsEnabled(Object __instance, boolean corsEnabled) {
        ((HttpConfiguration)__instance).corsEnabled = corsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static int get_port(Object __instance) {
        return ((HttpConfiguration)__instance).port;
    }
    @SuppressWarnings("unchecked")
    public static void set_port(Object __instance, int port) {
        ((HttpConfiguration)__instance).port = port;
    }
    @SuppressWarnings("unchecked")
    public static int get_testPort(Object __instance) {
        return ((HttpConfiguration)__instance).testPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_testPort(Object __instance, int testPort) {
        ((HttpConfiguration)__instance).testPort = testPort;
    }
    @SuppressWarnings("unchecked")
    public static Object get_host(Object __instance) {
        return ((HttpConfiguration)__instance).host;
    }
    @SuppressWarnings("unchecked")
    public static void set_host(Object __instance, Object host) {
        ((HttpConfiguration)__instance).host = (String)host;
    }
    @SuppressWarnings("unchecked")
    public static int get_sslPort(Object __instance) {
        return ((HttpConfiguration)__instance).sslPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_sslPort(Object __instance, int sslPort) {
        ((HttpConfiguration)__instance).sslPort = sslPort;
    }
    @SuppressWarnings("unchecked")
    public static int get_testSslPort(Object __instance) {
        return ((HttpConfiguration)__instance).testSslPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_testSslPort(Object __instance, int testSslPort) {
        ((HttpConfiguration)__instance).testSslPort = testSslPort;
    }
    @SuppressWarnings("unchecked")
    public static Object get_cors(Object __instance) {
        return ((HttpConfiguration)__instance).cors;
    }
    @SuppressWarnings("unchecked")
    public static void set_cors(Object __instance, Object cors) {
        ((HttpConfiguration)__instance).cors = (io.quarkus.vertx.http.runtime.cors.CORSConfig)cors;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ssl(Object __instance) {
        return ((HttpConfiguration)__instance).ssl;
    }
    @SuppressWarnings("unchecked")
    public static void set_ssl(Object __instance, Object ssl) {
        ((HttpConfiguration)__instance).ssl = (ServerSslConfig)ssl;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ioThreads(Object __instance) {
        return ((HttpConfiguration)__instance).ioThreads;
    }
    @SuppressWarnings("unchecked")
    public static void set_ioThreads(Object __instance, Object ioThreads) {
        ((HttpConfiguration)__instance).ioThreads = (java.util.OptionalInt)ioThreads;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_virtual(Object __instance) {
        return ((HttpConfiguration)__instance).virtual;
    }
    @SuppressWarnings("unchecked")
    public static void set_virtual(Object __instance, boolean virtual) {
        ((HttpConfiguration)__instance).virtual = virtual;
    }
    @SuppressWarnings("unchecked")
    public static Object get_limits(Object __instance) {
        return ((HttpConfiguration)__instance).limits;
    }
    @SuppressWarnings("unchecked")
    public static void set_limits(Object __instance, Object limits) {
        ((HttpConfiguration)__instance).limits = (ServerLimitsConfig)limits;
    }
    @SuppressWarnings("unchecked")
    public static Object get_body(Object __instance) {
        return ((HttpConfiguration)__instance).body;
    }
    @SuppressWarnings("unchecked")
    public static void set_body(Object __instance, Object body) {
        ((HttpConfiguration)__instance).body = (BodyConfig)body;
    }
    public static Object construct() {
        return new HttpConfiguration();
    }
}
